==> godot-3.2.2-beta3.tar.xz: godot-3.2.2-beta3/DONORS.md <==
# Donors to the Godot Engine project

Godot Engine is a non-profit project developed by a community of voluntary
contributors, as well as occasional paid contributors thanks to the financial
support of generous donors.

The ways to donate to the project, as well as details on how the funds are
used, are described on [Godot's website](https://godotengine.org/donate).

The following is a list of the current monthly donors, to be have their
generous deed immortalized in the next stable release of Godot Engine.

## Platinum sponsors

    Heroic Labs <https://heroiclabs.com>
    Interblock <http://interblockgaming.com>

## Gold sponsors

    Gamblify <https://www.gamblify.com>
    Moonwards <https://www.moonwards.com>

## Mini sponsors

    AD Ford
    Alan Beauchamp
    Anand Mallik
    Andrew Dunai
    Brandon Lamb
    Christian Baune
    Christopher Montesano
    Darkhan Baimyrza
    Darrin Massena
    Dov Zimring
    Edward Flick
    Gamechuck
    GameDev.net
    Grady
    Hein-Pieter van Braam
    Jacob McKenney
    Jasper Brooks
    Javary Co.
    Jeffery Chiu
    Justin Arnold
    Justo Delgado Baudí
    Kyle Szklenski
    Matthieu Huvé
    Maxim Karsten
    Mike King
    Nathan Warden
    Neal Gompa (Conan Kudo)
    Péter Magyar
    Slobodan Milnovic
    Stephan Lanfermann
    Steve
    Tristan Pemble
    VilliHaukka

## Gold donors

    David Gehrig
    David Graham
    David Snopek
    Ed Morley
    Florian Rämisch
    Jakub Grzesik
    Manuele Finocchiaro
    Officine Pixel S.n.c.
    Ronan Zeegers
    Sofox
    Taylor Ritenour
    Zaven Muradyan

    Asher Glick
    Austen McRae
    Bernhard Werner
    beVR
    Carlo Cabanilla
    Daniel James
    David Giardi
    Default Name
    eggs
    Florian Breisch
    Gamejunkey
    Javier Roman
    Jon Woodward
    Karl Werf
    Keinan Powers
    Klavdij Voncina
    Lex Steers
    Luke
    Maciej Pendolski
    Matthew Hillier
    Mohamed Ikbel Boulabiar
    Mored4u
    Rene
    Retro Village
    Rob Messick
    Ryan Badour
    Sandro Jenny
    Scott Wadden
    Sergey
    thechris
    Tom Langwaldt
    Tricky Fat Cat
    tukon
    William Wold

    Alex Khayrullin
    alice gambrell
    Chris Goddard
    Chris Serino
    Christian Padilla
    Conrad Curry
    Craig Smith
    Darrian Little
    Horváth Péter
    Ivan Trombley
    Joan Fons
    Joshua Flores
    Petr Malac
    Rami
    Rob
    Robert Willes
    Ronnie Ashlock
    SKison
    Thomas Bjarnelöf
    Unseen Domains
    Valryia
    Vincent Henderson
    Wojciech Chojnacki
    Xavier PATRICELLI

    Adam Nakonieczny
    Adam Neumann
    Adrian Demetrescu
    Alexander J Maynard
    Alexey Dyadchenko
    Andreas Funke
    André Frélicot
    aoshiwik
    Ben Powell
    Carlos de Sousa Marques
    Charlie Whitfield
    Chase Taranto
    Chris Petrich
    Christian Alexander Bjørklund Bøhler
    Christian Leth Jeppesen
    Christoph Schröder
    Codee Leaf
    Cody Parker
    Coldragon
    Craig Ostrin
    D
    Easypete
    Eric Monson
    Eugenio Hugo Salgüero Jáñez
    Fain
    flesk
    Gary Hulst
    gavlig
    GGGames.org
    Guilherme Felipe de C. G. da Silva
    Halom Vered
    Heath Hayes
    Isaac Clausman
    Jared White
    Jeff Nyte
    Joe Flood
    John G Gentzel
    Jose Malheiro
    Joshua Lesperance
    Juan Velandia
    Juraj Móza
    Kelteseth
    kickmaniac
    kinfox
    Lain Ballard
    Marcelo Dornbusch Lopes
    Markus Fehr
    Markus Wiesner
    Martin Eigel
    Matt Eunson
    m kaersten
    MuffinManKen
    Oliver Dick
    Oscar Campos
    Patrick Ting
    Paul Hocker
    Paul Von Zimmerman
    Pete Goodwin
    pl
    Ranoller
    Rob McInroy
    Rocknight Studios
    Ryan
    Samuel Judd
    Scott Pilet
    Sean Morgan
    Serban Serafimescu
    Sindre Sømme
    SleepCircle
    spilldata
    Stoned Xander
    TheLevelOfDetail .
    Thomas Kurz
    Tobias Bocanegra
    Urho
    William Foster
    Zhou Tuizhi
    Zie Weaver
    蕭惟允

## Silver donors

    1D_Inc
    Abraham Haskins
    Acheron
    Adam
    Adam Brunnmeier
    Adam  Carr
    Adam Long
    Adam McCurdy
    Adam Netzel
    Adam N Webber
    Adam Smeltzer
    Adam Szymański
    Adisibio
    Agustinus Arya
    Aidan O'Flannagain
    Aki Mimoto
    Alan Mervitz
    Alan Stice
    Albin Jonasson Svärdsby
    Alder Stefano
    AleMax
    Alessandro Senese
    Alexander Erlemann
    alex clavelle
    Allan Davis
    Allen Schade
    Andreas Evers
    Andreas Krampitz
    André Simões
    Andrew Thomas
    Anthony Avina
    Anthony Staunton
    AP Condomines
    Arda Erol
    Armin Preiml
    Arseniy M
    Arthur S. Muszynski
    Asger
    Ashley Claymore
    Aubrey Falconer
    Avencherus
    B A
    Balázs Batári
    Benedikt
    Ben Vercammen
    Bernd Jänichen
    Bjarne
    Black Block
    Blair Allen
    Bobby CC Wong
    Bram
    brian
    bugcaptor
    Burney Waring
    Cameron Meyer
    Carlo Sitaro
    Carl van der Geest
    Carwyn Edwards
    Cas Brugman
    Cassidy James
    Chris Brown
    Chris Chapin
    Christian Winter
    Christoffer Sundbom
    Christoph Brodmann
    Christophe Gagnier
    Christopher Schmitt
    Christoph Woinke
    Clay Heaton
    Cole Johnson
    Curt King
    Daniel Johnson
    Daniel Kimblad
    Daniel Tebbutt
    David May
    David Woodard
    DiCola Jamn
    Dominic Cooney
    Dominik Wetzel
    Donn Eddy
    Dragontrapper
    Dr Ewan Murray
    Duobix
    Duodecimal
    Dylan Todd
    Eduardo Teixeira
    Edward Herbert
    Edward Swartz
    Egon Elbre
    Elgenzay
    Elias Nykrem
    Elmeri '- Duy Kevin Nguyen
    Ephemeral
    Eric Ellingson
    Eric Rogers
    Eric Williams
    Erkki Seppälä
    Evan Rose
    Fancy Ants Studios
    Fekinox
    Felix Bohmann
    Felix Kollmann
    Flaredown
    Forty Doubleu
    fox
    FuDiggity
    Gadzhi Kharkharov
    gamedev by Celio
    Gary Thomas
    George Marques
    Greg Olson
    GREGORY C FEIN
    Greyson Richey
    Grid
    Guillaume Audirac
    Guldoman
    Hal A
    Heribert Hirth
    Hunter Jones
    Hylpher
    Ichiro Dohi
    Iiari
    iKlem
    IndustrialRobot
    Ivan Nikolaev
    Jacob
    Jaiden Gerig
    Jaime Ruiz-Borau Vizárraga
    Jako Danar
    James A F Manley
    Janders
    Jannik Gröger
    JARKKO PARVIAINEN
    Jeff Hungerford
    Jennifer Graves
    Jesse Dubay
    Joel Fivat
    Joel Höglund
    Joel Setterberg
    John Gabriel
    John Walker
    Jomei Jackson
    Jonas
    Jonas Bernemann
    Jonas Rudlang
    Jonas Yamazaki
    Jonatan R
    Jonathan G
    Jon Bonazza
    Jon Sully
    Jorge Caballero
    Jose Aleman
    Jose C. Rubio
    Joseph Catrambone
    Josh Mitchell
    Juanfran
    Judd
    Julian Murgia
    JungleRobba
    Justin Hamilton
    Justin Spedding
    KaDokta
    Karel Němec
    Kauzig
    Keedong Park
    Keith Bradner
    Kent Jofur
    Kevin McPhillips
    Kiri Jolly
    Kiyohiro Kawamura (kyorohiro)
    Kjetil Haugland
    Klagsam
    KsyTek Games
    Kuan Cheang
    kycho
    Kyle Appelgate
    Laurent Tréguier
    Leonardo Dimano
    Levi Lindsey
    Lin Chear
    Linus Lind Lundgren
    Lionel Gaillard
    Lukáš Rendvanský
    Luigi Renna
    LunaticInAHat
    Lurkars
    Major Haul
    Malcolm
    Malik Ahmed
    Malik Nejer
    Markus Michael Egger
    Martin Holas
    Martin Liška
    Marvin
    Mathieu Rimelen
    Matt Edwards
    Matthew Little
    Mauro Pellegrini
    Max Fiedler
    Maxime Blade
    Maxwell
    Megasploot
    Melissa Mears
    mewin
    mhilbrunner
    Michael Dürwald
    Michael Haney
    Michael Labbe
    Michał Skwarek
    Mikael Olsson
    Mikayla
    Mike Birkhead
    Mike Cunningham
    Mitchell J. Wagner
    MoM
    Mored4u
    Nathan Fish
    Natrim
    nee
    Neil Blakey-Milner
    Neil Wang
    Nerdforge
    Nicholas
    Nicholas Girga
    Nick Macholl
    Niclas Eriksen
    Nicolás Montaña
    Nicolas SAN AGUSTIN
    NZ
    Oleg Reva
    Olivier
    Omar Delarosa
    Oscar Norlander
    Pan Ip
    Patrick Nafarrete
    Paul Gieske
    Paul Mason
    Paweł Kowal
    Pedro Assuncao
    Penguin
    Philip Cohoe
    Point08
    Rad Cat
    Rafa Laguna
    rainerLinux
    Remi Rampin
    Rémi Verschelde
    Ricardo Alcantara
    Richard Diss
    Richard Ivánek
    Robert Farr (Larington)
    Robert Hernandez
    Roger Smith
    Roland Rząsa
    Roman Tinkov
    Ronald Ho Hip (CrimsonZA)
    Ronan
    Ryan Groom
    Ryan Hentz
    Sam Edson
    Samuele Zolfanelli
    Scott D. Yelich
    Scott Longley
    ScottMakesGames
    Sebastian Michailidis
    Sebastian Vetter
    Sergio Mello-Grand
    Shane
    Shane Sicienski
    Shane Spoor
    Siim Raidma
    Simon Jonas Larsen
    Simon Wenner
    Sintinium
    SK
    smbe19
    smo1704
    Stefano Caronia
    Steve Cloete
    Svenne Krap
    Taylor Fahlman
    Terry
    tezuvholovdr
    thomas
    Thomas Bechtold
    Thomas Detoy
    Thomas Kelly
    Tim Drumheller
    Timothy B. MacDonald
    Title Plinsut
    Tobbun
    Tom Glenn
    Toni Duran
    Torgeir Lilleskog
    Torsten Crass
    Travis O'Brien
    Trent Skinner
    Troy Bonneau
    Tryggve Sollid
    Turgut Temucin
    Tyler Compton
    Tyler Stafos
    UltyX
    Vaughan Ling
    Victor
    Vigilant Watch
    Vincent Cloutier
    waka nya
    Wayne Haak
    werner mendizabal
    Wiley Thompson
    Will
    William Hogben
    Wyatt Goodin
    Yegor
    Yuri Sizov

## Bronze donors

There are even more donors that support the project with a small monthly donation.
Every bit counts and we thank every one of them for their amazing support!

==> godot-3.2.4-beta3.tar.xz: godot-3.2.4-beta3/DONORS.md <==
# Donors to the Godot Engine project

Godot Engine is a non-profit project developed by a community of voluntary
contributors, as well as occasional paid contributors thanks to the financial
support of generous donors.

The ways to donate to the project, as well as details on how the funds are
used, are described on [Godot's website](https://godotengine.org/donate).

The following is a list of the current monthly donors, to be have their
generous deed immortalized in the next stable release of Godot Engine.

## Platinum sponsors

    Gamblify <https://www.gamblify.com>
    Heroic Labs <https://heroiclabs.com>
    Spiffcode <http://www.spiffcode.com>

## Gold sponsors

    None currently, become one! <https://godotengine.org/donate>

## Silver sponsors

    ASIFA-Hollywood <https://www.asifa-hollywood.org>
    Moonwards <https://www.moonwards.com>
    Zenva Academy <https://academy.zenva.com>

## Bronze sponsors

    Brandon Lamb
    Garry Newman
    Hunter Dickson

## Mini sponsors

    AD Ford
    albinaask
    Alejandro Saucedo
    alex brown
    Andrew Dunai
    Christian Baune
    Christoffer Sundbom
    Christopher Montesano
    Darrin Massena
    David Mydlarz
    Digital Grows
    Dov Zimring
    Edward Flick
    Gamechuck
    GameDev.net
    Hein-Pieter van Braam
    Jacob McKenney
    Jasper Brooks
    Javary Co.
    Jeffery Chiu
    John G Gentzel
    Jonah Stich
    Justin Arnold
    Marcel Kräml
    Matthieu Huvé
    Maxim Karsten
    Mike King
    Nathan Warden
    Neal Gompa (Conan Kudo)
    Patrick Horn
    Patrick Schmidt
    Péter Magyar
    Ronnie Cheng
    Slobodan Milnovic
    Stephan Lanfermann
    Steve
    Thomas Krampl
    Tristan Pemble
    VilliHaukka
    Violin Iliev

## Gold donors

    Andrew Morsillo
    Asher Glick
    Austen McRae
    Bernhard Werner
    Carlo Cabanilla
    Chris Goddard
    Christopher Case
    Daniel James
    David Gehrig
    David Snopek
    Ed Morley
    eggs
    Ellen Poe
    Florian Breisch
    Florian Rämisch
    Forge
    Gamejunkey
    Grady
    Jakub Grzesik
    Javier Roman
    Jeff Nyte
    Joan Fons
    Jon Woodward
    Karl Werf
    Klavdij Voncina
    Lex Steers
    Luke
    Maciej Pendolski
    Manuele Finocchiaro
    Markus Wiesner
    Mason Bially
    Matthew Hillier
    Michael
    m kaersten
    Mohamed Ikbel Boulabiar
    Monster Vial
    Officine Pixel S.n.c.
    Rami
    Rene
    Rene Tailleur
    Retro Village
    Rob Messick
    Roland Fredenhagen
    Ronan Zeegers
    Sandro Jenny
    Sarksus
    Sean
    Sergey
    SIM KIM SIA
    Sofox
    Taylor Ritenour
    Tom Langwaldt
    Tricky Fat Cat
    tukon
    William Wold
    xagonist
    Zaven Muradyan

    Aaron Winter
    Adam Nakonieczny
    Alexander J Maynard
    Alex de la Mare
    Alex Khayrullin
    alice gambrell
    Andreas Funke
    Andrew Harris
    Antoni Batchelli
    Arisaka Mayuki
    Barugon
    Ben Botwin
    Charlie Whitfield
    Chase Taranto
    Chelsea Hash
    Chris Petrich
    Chris Serino
    Christian Leth Jeppesen
    Cody Brooks
    Cody Parker
    Conrad Curry
    Craig Ostrin
    Craig Smith
    D
    Darrian Little
    Dev To be curious
    Digital Denizen
    Donn Eddy
    Easypete
    Edgar Sun
    Eugenio Hugo Salgüero Jáñez
    flesk
    F S
    Gabrielius Vaiškūnas
    Gary Hulst
    gavlig
    GGGames.org
    GiulianoB
    Green Fox
    Guilherme Felipe de C. G. da Silva
    Heath Hayes
    Hoai Nam Tran
    Horváth Péter
    Hu Hund
    James Couzens
    Jared
    Jared White
    Joel Fivat
    Joel Höglund
    Jose Malheiro
    Joseph Crane
    Joshie Sparks
    Joshua Flores
    Joshua Lesperance
    Juan Velandia
    Judd
    Julian Todd
    Juraj Móza
    JUSTIN CARROLL
    Justo Delgado Baudí
    Kelteseth
    kickmaniac
    kinfox
    kuku
    Lachie
    Lain Ballard
    Leo Fidel R Liban
    Luc-Frédéric Langis
    luka duren
    MadScientistCarl
    Marcelo Dornbusch Lopes
    Marisa Clardy
    Markus Fehr
    Martin Eigel
    Martin Kotz
    Martin Soucek
    Matt Eunson
    Michael
    Michael Dürwald
    Mikado069
    MuffinManKen
    Nick Abousselam
    Oliver Dick
    Oscar Campos
    Patrick Ting
    Paul Hocker
    Paul Von Zimmerman
    Pedro Silva
    Pete Goodwin
    Petr Malac
    PhaineOfCatz
    pl
    Ranoller
    Raymond Harris
    razmie
    Ricardo Alcantara
    Robert Willes
    Rob McInroy
    Rocknight Studios
    Ronnie Ashlock
    Ryan Wilson
    Samuel Judd
    Scott Pilet
    Sean Morgan
    Sean Robertson
    Sébastien
    Sergey Minakov
    Shishir Tandale
    SKison
    spilldata
    Steven Landow
    Stoned Xander
    TheLevelOfDetail .
    Thomas Bjarnelöf
    Thomas Kurz
    Tim Howard
    Timothy Pulliam
    Tobias Bocanegra
    Trent Fehl
    Valryia
    VikFro
    Vincent Cloutier
    Vojtěch
    voxelv
    William Foster
    Wojciech Chojnacki
    xzibiting
    Zhou Tuizhi
    Zie Weaver
    Zoran Kukulj

## Silver donors

    1D_Inc
    Aaron Passchier
    Abraham Haskins
    Acheron
    Adam
    Adam Brunnmeier
    Adam Carr
    Adam Long
    Adam McCurdy
    Adam N Webber
    Adam Smeltzer
    Adam Szymański
    Adisibio
    Agar3s - Giovanny Beltrán
    Agustinus Arya
    Ahmet Kalyoncu
    Aidan O'Flannagain
    Aki Mimoto
    Alan Beauchamp
    Albin Jonasson Svärdsby
    Alder Stefano
    AleMax
    Alessandro Senese
    Alexander Erlemann
    Alexandre Beaudoin
    alex clavelle
    Ali Al-Khalifa
    Allan Davis
    Allen Schade
    Andreas Krampitz
    André Simões
    Andre Stackhouse
    andrew james morris
    Andrew Mansuetti
    Andrew Rosenwinkel
    Andrew Thomas
    Ano Nim
    Anthony Avina
    AP Condomines
    Arda Erol
    Armin Preiml
    Arseniy M
    Arthur S. Muszynski
    Ashley Claymore
    Ashton Scott Snapp
    Astier Mickael
    Aubrey Falconer
    B A
    Balázs Batári
    Balázs Kondákor
    Bartosz Bielecki
    Bekhoucha Danyl
    Benedikt
    Ben Vercammen
    Bernd Jänichen
    Bjarne Voigtländer
    Black Block
    Blair Allen
    Bobby CC Wong
    Borkzilla
    Boyd Trolinger
    Bram
    brian
    Brian mc gowan
    Brodie Fairhall
    Burney Waring
    Caleb Gartner
    Cameron Meyer
    Carlos Cejudo
    Carl van der Geest
    Carwyn Edwards
    Cas Brugman
    Cassidy James
    Chad Steadman
    Chris Chapin
    Chris Jagusch
    Chris Langford
    Christian Clavet
    Christian Winter
    Christoffer Dahlblom
    Christophe Gagnier
    Christopher Schmitt
    Christoph Woinke
    Clay Heaton
    Conall O
    Curt King
    Cyrelouyea
    CzechBlueBear
    Daniel Johnson
    DanielMaximiano
    Daniel Tebbutt
    Danny Welch
    Daren Scot Wilson
    Dave Walker
    David Bôle
    David May
    David Woodard
    Dmitry Fisher
    Dmytro Korchynskyi
    Dominik Wetzel
    Dragontrapper
    Dr Ewan Murray
    Dr.Raccoon
    Duobix
    Duodecimal
    Eduardo Teixeira
    Edward Herbert
    Edward Swartz
    Eelco F Hillenius
    Egon Elbre
    Elgenzay
    Elias Nykrem
    Ephemeral
    Eric Ellingson
    Eric Williams
    Erkki Seppälä
    ET Garcia
    Evan Rose
    Fain
    Faisal Alkubaisi
    Fancy Ants Studios
    Fekinox
    Felix Bohmann
    Flaredown
    Forty Doubleu
    Francois Holland
    Frank
    FuDiggity
    Gadzhi Kharkharov
    gamedev by Celio
    Gary Thomas
    George Marques
    Greg Lincoln
    Greg Olson
    GREGORY C FEIN
    Greyson Richey
    Grid
    Guillaume Audirac
    Guillaume Pham Ngoc
    Guldoman
    Gustavo Loureiro dos Reis
    Hal A
    helija
    Heribert Hirth
    Hunter Jones
    Hylpher
    Ian Williams
    Iiari
    iKlem
    IndustrialRobot
    Jackson Harmer
    Jacob
    Jaguar
    Jaiden Gerig
    Jaime Ruiz-Borau Vizárraga
    Jake D
    Jake Huxell
    Jako Danar
    James
    James A F Manley
    James Thomas
    Jamiee H
    Jamie Massey
    Janders
    JARKKO PARVIAINEN
    Jason Uechi
    Jean-Baptiste LEPESME
    Jeff Hungerford
    Jennifer Graves
    Jesse Dubay
    Joe Alden
    Joe Klemmer
    John Gabriel
    Jonas
    Jonas Bernemann
    Jonas Rudlang
    Jonas Yamazaki
    Jonatan R
    Jonathan G
    Jon Bonazza
    Jon Oakes
    Jon Sully
    Jordy Goodridge
    Jorge Antunes
    Jose C. Rubio
    Joseph Catrambone
    Josh Mitchell
    Joshua Southerland
    Juanfran
    Julian Murgia
    June Little
    JungleRobba
    Justin Calleja
    Justin Oaksford
    Justin Spedding
    KaDokta
    Kalin
    Karel Němec
    Kauzig
    Keedong Park
    Keinan Powers
    Keith Bradner
    Kent Jofur
    Kevin McPhillips
    Kiri Jolly
    Kjetil Haugland
    Kristian Nygaard Jensen
    KsyTek Games
    Kuan Cheang
    kycho
    Kyle Szklenski
    Kyuppin
    Laurent CHEA
    Laurent Tréguier
    LEMMiNO
    Leonardo Dimano
    Lin Chear
    Linus Lind Lundgren
    Lionel Gaillard
    Luigi Renna
    LunaticInAHat
    Lurkars
    Major Haul
    Malcolm
    Marco Lardelli
    Mark Jad
    Mark Krenz
    Markus Martin
    Markus Michael Egger
    Martin FIbik
    Martin Holas
    Martin Linklater
    Martin Liška
    Martin Trbola
    Marvin
    Mathieu
    Matt Edwards
    Matthew Booe
    Max Brister
    Max Fiedler
    Maxime Blade
    Maxwell
    Megasploot
    Melissa Mears
    mewin
    Michael Haney
    Michał Skwarek
    Mikayla
    Mike Birkhead
    Mike Cunningham
    Mitchell J. Wagner
    Molinghu
    Molly Jameson
    MoM
    MrAZIE
    Nathan Fish
    Nathaniel
    Natrim
    nee
    Neil Blakey-Milner
    Neil Wang
    Nerdforge
    Nerdyninja
    Nicholas
    Nicholas Girga
    Nick Allen
    Nick Macholl
    Niclas Eriksen
    Nicolas Goll-Perrier
    Nicolás Montaña
    Nicolas SAN AGUSTIN
    NZ
    OKV
    Oleg Reva
    Oleksandr Kryvonos
    Olivier
    Omar Delarosa
    Oscar Domingo
    Oscar Norlander
    Parinya Teerakasemsuk
    Patrick Dully
    Patrick Nafarrete
    Paul Gieske
    Paul Mason
    Paweł Kowal
    Paweł Łyczkowski
    Pedro Assuncao
    Penguin
    Petrus Prinsloo
    Philip Cohoe
    Piotr Góral
    Point08
    Preethi Vaidyanathan
    Price Comstock
    pwab
    Rafa Laguna
    Raffaele Aramo
    Remi Rampin
    Rémi Verschelde
    Reneator
    Richard Diss
    Richard Ivánek
    Robert Farr (Larington)
    Robert Larnach
    Rob Ruana
    Roger Smith
    Roland Rząsa
    Roman Tinkov
    Ronald Ho Hip (CrimsonZA)
    Ronan
    Ronny Mühle
    Ross Squires
    Ryan Groom
    Sam Caulfield
    Sam Edson
    Samuele Zolfanelli
    sayaks
    Scott D. Yelich
    Scott Longley
    ScottMakesGames
    Sebastian Michailidis
    Sebastian Vetter
    Shaher
    Shane
    Shane Sicienski
    Shane Spoor
    Shiomi - Duy Kevin Nguyen
    Siim Raidma
    Simon Jonas Larsen
    Simon Schoenenberger
    Simon Wenner
    Skalli
    smbe19
    smo1704
    soft circles
    Squirrel
    Stefano Caronia
    Steve Cloete
    Svenne Krap
    tadashi endo
    tannhauser_gate
    Terry
    Theodore Lindsey
    TheTrainDoctor
    TheVoiceInMyHead
    thomas
    Thomas Bechtold
    Thomas Detoy
    Thomas Kelly
    Tim Drumheller
    Tim Erskine
    Tim Gleason
    Timothy B. MacDonald
    Tobbun
    Tobias Bradtke
    Toni Duran
    Tony Zhao
    Torgeir Lilleskog
    Torsten Crass
    Travis O'Brien
    Trent Skinner
    tril zerobyte
    Triptych
    Triumph263 .
    Troy Bonneau
    Tryggve Sollid
    Turgut Temucin
    Tyler Compton
    Tyler Stafos
    UltyX
    Uther
    Vaughan Ling
    Victor
    Vigilant Watch
    Viktor Ismagilov
    Vitor Balbio
    Vladimir Savin
    Vladislav Smirnov
    Výrus Hemomancer
    waka nya
    Wayne Haak
    werner mendizabal
    Wiley Thompson
    Will
    William Edwards
    William F Siqueira
    William Hogben
    Wyatt Goodin
    Yegor Smirnov
    YiYin Gu
    Zak Stephens
    ΒΑΣΙΛΗΣ ΓΕΩΡΓΑΚΟΠΟΥΛΟΣ
    蕭惟允
    郝晨煜

## Bronze donors

There are even more donors that support the project with a small monthly donation.
Every bit counts and we thank every one of them for their amazing support!
